/**
@license
Copyright (c) 2018 The Polymer Project Authors. All rights reserved.
This code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt
The complete set of authors may be found at http://polymer.github.io/AUTHORS.txt
The complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt
Code distributed by Google as part of the polymer project is also
subject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt
*/
export const ReduxMixin = (store) => (baseElement) => class extends baseElement {
    constructor(...args) {
        super(...args);
        Object.assign(this, this.mapDispatchToProps(store.dispatch));
    }
    connectedCallback() {
        if (super.connectedCallback) {
            super.connectedCallback();
        }
        this._storeUnsubscribe = store.subscribe(() => this._stateChanged(store.getState()));
        this._stateChanged(store.getState());
    }
    disconnectedCallback() {
        this._storeUnsubscribe();
        if (super.disconnectedCallback) {
            super.disconnectedCallback();
        }
    }
    _stateChanged(state) {
        Object.assign(this, this.mapStateToProps(state));
    }
    mapStateToProps(_state) {
        return {};
    }
    mapDispatchToProps(_dispatch) {
        return {};
    }
};
//# sourceMappingURL=redux-mixin.js.map